CochranArmitage_CI_rx2: The Cochran-Armitage confidence interval for trend in the linear model
Description
The Cochran-Armitage confidence interval for trend in the linear model
Described in Chapter 5 "The Ordered rx2 Table"
Usage
CochranArmitage_CI_rx2(n, a = seq_len(nrow(n)), alpha = 0.05)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.