Fisher_exact_test_2x2: The Fisher exact test for association in 2x2 tables
Description
The Fisher exact test for association in 2x2 tables
Described in Chapter 4 "The 2x2 Table"
Usage
Fisher_exact_test_2x2(n, statistic = "Pearson")
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed counts (a 2x2 matrix)
statistic
'hypergeometric' (i.e. Fisher-Irwin; default), 'Pearson', or 'LR' (likelihood ratio)
Table orientation
In most study designs, rows designate a grouping of the data, for
instance, into treatment or exposure groups, while the columns indicate a
dichotomous outcome, usually with the first column representing the outcome
of interest. This designation of rows and columns may not be relevant in all
study designs, please see the introduction to chapter 4 for details.