Goodman_Wilson_score_CIs_1xc: The Goodman Wilson score simultaneous intervals for the multinomial probabilities
Description
The Goodman Wilson score simultaneous intervals for the multinomial probabilities
(with Bonferroni adjustment)
Described in Chapter 3 "The 1xc Table and the Multinomial Distribution"
Usage
Goodman_Wilson_score_CIs_1xc(n, alpha = 0.05)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed counts (a 1xc vector, where c is the number of categories)