Kendalls_tau_b_rxc: Kendall's tau-b with confidence interval based on the Fieller standard deviation
Description
Kendall's tau-b with confidence interval based on the Fieller standard deviation
Described in Chapter 7 "The rxc Table"
Usage
Kendalls_tau_b_rxc(n, alpha = 0.05)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed table (an rxc matrix)
alpha
the nominal significance level, used to compute a 100(1-alpha)% confidence interval