Learn R Programming

contingencytables (version 3.1.0)

MOVER_Wilson_score_CI_paired_2x2: The MOVER Wilson score confidence interval for the ratio of paired probabilities

Description

The MOVER Wilson score confidence interval for the ratio of paired probabilities

Described in Chapter 8 "The Paired 2x2 Table"

Usage

MOVER_Wilson_score_CI_paired_2x2(n, alpha = 0.05)

Value

An object of the contingencytables_result class, basically a subclass of base::list(). Use the utils::str() function to see the specific elements returned.

Arguments

n

the observed counts (a 2x2 matrix)

alpha

the nominal level, e.g. 0.05 for 95% CIs

Examples

Run this code
MOVER_Wilson_score_CI_paired_2x2(bentur_2009)
MOVER_Wilson_score_CI_paired_2x2(cavo_2012)

Run the code above in your browser using DataLab