Learn R Programming

contingencytables (version 3.1.0)

McNemar_asymptotic_test_paired_2x2: The McNemar asymptotic test

Description

The McNemar asymptotic test

Described in Chapter 8 "The Paired 2x2 Table"

Usage

McNemar_asymptotic_test_paired_2x2(n)

Value

An object of the contingencytables_result class, basically a subclass of base::list(). Use the utils::str() function to see the specific elements returned.

Arguments

n

the observed table (a 2x2 matrix)

Table orientation

In most study designs, rows designate a grouping of the data, for instance, into treatment or exposure groups, while the columns indicate a dichotomous outcome, usually with the first column representing the outcome of interest. This designation of rows and columns may not be relevant in all study designs, please see the introduction to chapter 8 for details.

Examples

Run this code
McNemar_asymptotic_test_paired_2x2(bentur_2009)
McNemar_asymptotic_test_paired_2x2(cavo_2012)
McNemar_asymptotic_test_paired_2x2(ezra_2010)

Run the code above in your browser using DataLab