Learn R Programming

contingencytables (version 3.1.0)

Pearson_LR_homogeneity_test_stratified_2x2: The Pearson chi-squared and likelihood ratio tests for homogeneity over strata

Description

The Pearson chi-squared and likelihood ratio tests for homogeneity over strata

Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"

Usage

Pearson_LR_homogeneity_test_stratified_2x2(n, link = "logit")

Value

An object of the contingencytables_result class, basically a subclass of base::list(). Use the utils::str() function to see the specific elements returned.

Arguments

n

the observed table (a 2x2xk matrix, where k is the number of strata)

link

the link function ('linear', 'log', or 'logit')

Examples

Run this code
# Smoking and lung cancer (Doll and Hill, 1950)
Pearson_LR_homogeneity_test_stratified_2x2(doll_hill_1950)

# Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989)
Pearson_LR_homogeneity_test_stratified_2x2(hine_1989)

Run the code above in your browser using DataLab