Learn R Programming

contingencytables (version 3.1.0)

Peto_homogeneity_test_stratified_2x2: The Peto test for homogeneity of odds ratios over strata

Description

The Peto test for homogeneity of odds ratios over strata

Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"

Usage

Peto_homogeneity_test_stratified_2x2(n)

Arguments

n

the observed table (a 2x2xk matrix, where k is the number of strata)

Examples

Run this code
# Smoking and lung cancer (Doll and Hill, 1950)
Peto_homogeneity_test_stratified_2x2(doll_hill_1950)

# Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989)
Peto_homogeneity_test_stratified_2x2(hine_1989)

Run the code above in your browser using DataLab