powered by
The Quesenberry-Hurst Wilson score simultaneous intervals for the multinomial probabilities
(with Scheffe adjustment)
Described in Chapter 3 "The 1xc Table and the Multinomial Distribution"
QuesenberryHurst_Wilson_score_CIs_1xc(n, alpha = 0.05)
An object of the contingencytables_result class, basically a subclass of base::list(). Use the utils::str() function to see the specific elements returned.
base::list()
utils::str()
the observed counts (a 1xc vector, where c is the number of categories)
the nominal level, e.g. 0.05 for 95% CIs
# Genotype counts for SNP rs 6498169 in RA patients QuesenberryHurst_Wilson_score_CIs_1xc(n = snp6498169$complete$n)
Run the code above in your browser using DataLab