Learn R Programming

contingencytables (version 3.1.0)

Wald_CI_2x2: The Wald confidence interval for the difference between probabilities

Description

The Wald confidence interval for the difference between probabilities

Described in Chapter 4 "The 2x2 Table"

Usage

Wald_CI_2x2(n, alpha = 0.05)

Value

An object of the contingencytables_result class, basically a subclass of base::list(). Use the utils::str() function to see the specific elements returned.

Arguments

n

the observed counts (a 2x2 matrix)

alpha

the nominal level, e.g. 0.05 for 95% CIs

Table orientation

In most study designs, rows designate a grouping of the data, for instance, into treatment or exposure groups, while the columns indicate a dichotomous outcome, usually with the first column representing the outcome of interest. This designation of rows and columns may not be relevant in all study designs, please see the introduction to chapter 4 for details.

Examples

Run this code
# An RCT of high vs standard dose of epinephrine (Perondi et al., 2004):
Wald_CI_2x2(n = perondi_2004)
# The association between CHRNA4 genotype and XFS (Ritland et al., 2007):
Wald_CI_2x2(n = ritland_2007)

Run the code above in your browser using DataLab