Wald_CI_OR_Laplace_paired_2x2: The Wald confidence interval for the conditional odds ratio with
Laplace adjustment
Description
The Wald confidence interval for the conditional odds ratio with
Laplace adjustment
Described in Chapter 8 "The Paired 2x2 Table"
Usage
Wald_CI_OR_Laplace_paired_2x2(n, alpha = 0.05)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.