Learn R Programming

contingencytables (version 3.1.0)

contingencytables_result: contingencytables_result class

Description

A class for output of the main functions on this package

Usage

contingencytables_result(statistics, print_structure)

Value

an object of class contingencytables_result

Arguments

statistics

Either a value or a list of values to be filled by print_format

print_structure

Either a string of a function instructing how to print the values from statistics

Author

Waldir Leoncio

See Also

print.contingencytables_result