Learn R Programming

contingencytables (version 3.1.0)

the_1xc_table_CIs: The 1xc table CIs

Description

The 1xc table CIs

Usage

the_1xc_table_CIs(n, alpha = 0.05)

Value

NULL. This function should be called for its printed output

Arguments

n

the observed counts (a 1xc vector, where c is the number of categories)

alpha

the nominal level, e.g. 0.05 for 95# CIs

Examples

Run this code
# Genotype counts for SNP rs 6498169 in RA patients
the_1xc_table_CIs(n = snp6498169$complete$n)

Run the code above in your browser using DataLab