Learn R Programming

contingencytables (version 3.1.0)

the_paired_2x2_table_CIs_OR: The Paired 2x2 table CIs OR

Description

The Paired 2x2 table CIs OR

Usage

the_paired_2x2_table_CIs_OR(n, alpha = 0.05)

Value

NULL. This function should be called for its printed output.

Arguments

n

frequency matrix

alpha

type I error

Table orientation

In most study designs, rows designate a grouping of the data, for instance, into treatment or exposure groups, while the columns indicate a dichotomous outcome, usually with the first column representing the outcome of interest. This designation of rows and columns may not be relevant in all study designs, please see the introduction to chapter 8 for details.

Examples

Run this code
the_paired_2x2_table_CIs_OR(ezra_2010)

Run the code above in your browser using DataLab