BreslowDay_homogeneity_test_stratified_2x2: The Breslow-Day test of homogeneity of odds ratios over strata
Description
The Breslow-Day test of homogeneity of odds ratios over strata with
Tarone correction
Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"
Usage
BreslowDay_homogeneity_test_stratified_2x2(n)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed table (a 2x2xk matrix, where k is the number of strata)