Cochran_Q_test_stratified_2x2: The Cochran Q test of homogeneity of effects over strata
Description
The Cochran Q test of homogeneity of effects over strata
Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"
Usage
Cochran_Q_test_stratified_2x2(n, link = "linear", estimatetype = "MH")
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed table (a 2x2xk matrix, where k is the number of strata)
link
the link function ('linear', 'log', or 'logit')
estimatetype
Mantel-Haenszel or inverse variance estimate ('MH' or 'IV')