FleissEveritt_test_paired_cxc: The Fleiss-Everitt version of the Stuart test for marginal homogeneity
Description
The Fleiss-Everitt version of the Stuart test for marginal homogeneity
Described in Chapter 9 "The Paired cxc Table"
Usage
FleissEveritt_test_paired_cxc(n)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.