InverseVariance_estimate_stratified_2x2: The inverse variance estimate of the overall effect across strata
Description
The inverse variance estimate of the overall effect across strata
Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"
Usage
InverseVariance_estimate_stratified_2x2(n, link = "logit")
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.
Arguments
n
the observed table (a 2x2xk matrix, where k is the number of strata)