MOVER_Wilson_score_CI_paired_2x2: The MOVER Wilson score confidence interval for the ratio of paired probabilities
Description
The MOVER Wilson score confidence interval for the ratio of paired probabilities
Described in Chapter 8 "The Paired 2x2 Table"
Usage
MOVER_Wilson_score_CI_paired_2x2(n, alpha = 0.05)
Value
An object of the contingencytables_result class,
basically a subclass of base::list(). Use the utils::str() function
to see the specific elements returned.