powered by
A class for output of the main functions on this package
contingencytables_result(statistics, print_structure)
an object of class contingencytables_result
contingencytables_result
Either a value or a list of values to be filled by print_format
Either a string of a function instructing how to print the values from statistics
statistics
Waldir Leoncio
print.contingencytables_result