Learn R Programming

contingencytables (version 3.1.0)

stratified_2x2_tables: Stratified 2x2 tables

Description

Stratified 2x2 tables

Usage

stratified_2x2_tables(n, alpha = 0.05)

Value

NULL. This function should be called for its printed output

Arguments

n

the observed table (a 2x2xk matrix, where k is the number of strata)

alpha

the nominal level, e.g. 0.05 for 95% CIs

Examples

Run this code
# Smoking and lung cancer (Doll and Hill, 1950)
stratified_2x2_tables(doll_hill_1950)

# Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989)
stratified_2x2_tables(hine_1989)

Run the code above in your browser using DataLab