powered by
Stratified 2x2 tables
stratified_2x2_tables(n, alpha = 0.05)
NULL. This function should be called for its printed output
the observed table (a 2x2xk matrix, where k is the number of strata)
the nominal level, e.g. 0.05 for 95% CIs
# Smoking and lung cancer (Doll and Hill, 1950) stratified_2x2_tables(doll_hill_1950) # Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989) stratified_2x2_tables(hine_1989)
Run the code above in your browser using DataLab