powered by
The 1xc table CIs
the_1xc_table_CIs(n, alpha = 0.05)
NULL. This function should be called for its printed output
the observed counts (a 1xc vector, where c is the number of categories)
the nominal level, e.g. 0.05 for 95# CIs
# Genotype counts for SNP rs 6498169 in RA patients the_1xc_table_CIs(n = snp6498169$complete$n)
Run the code above in your browser using DataLab