powered by
The Paired 2x2 table tests
the_paired_2x2_table_tests(n, gamma = 1e-04, num_pi_values = 1000L)
NULL. This function should be called for its printed output.
frequency matrix
parameter for the Berger and Boos procedure
number of values to use in the partition of the nuisance parameter space (default=1000)
the_paired_2x2_table_tests(bentur_2009) the_paired_2x2_table_tests(cavo_2012, gamma = 0, num_pi_values = 10) the_paired_2x2_table_tests(ezra_2010, gamma = 0, num_pi_values = 20)
Run the code above in your browser using DataLab